# Introduction

Gracula is a very simple Twitter api.

You can use Twitter api without installing any other pip.

This package can be done without OAuth.

It consists of the standard library of python3.
